@@ -162,7 +162,7 @@ KScienceSaver::KScienceSaver( WId id, bool s, bool gP )
         do_refresh( QRect ( 0, 0, width(), height() ) );
     }
 
-    connect( &timer, SIGNAL( timeout() ), SLOT( slotTimeout() ) );
+    connect( &timer, SIGNAL(timeout()), SLOT(slotTimeout()) );
     timer.start( SCI_MAX_SPEED - speed[mode] );
 }
 
@@ -581,7 +581,7 @@ void KScienceSaver::readSettings()
 	for(int i=0; i < MAX_MODES; i++)
 	{
 		sMode.setNum( i );
-		group = KGlobal::config()->group( "Mode" + sMode );
+		group = KGlobal::config()->group( QLatin1String( "Mode" ) + sMode );
 		moveX[i]     = group.readEntry(  "MoveX",     SCI_DEFAULT_MOVEX);
 		moveY[i]     = group.readEntry(  "MoveY",     SCI_DEFAULT_MOVEY);
 		size[i]      = group.readEntry(  "Size",      SCI_DEFAULT_SIZE);
@@ -889,26 +889,26 @@ KScienceSetup::KScienceSetup(  QWidget *parent )
 		c->addItem( modeInfo[i].name );
 	c->setCurrentRow( mode );
 	c->setFixedHeight( 5 * c->fontMetrics().height() );
-	connect( c, SIGNAL( currentRowChanged( int ) ), SLOT( slotMode( int ) ) );
+	connect( c, SIGNAL(currentRowChanged(int)), SLOT(slotMode(int)) );
 	ltm->addWidget( c );
 
 	// inverse
 	QCheckBox *cbox = checkInverse = new QCheckBox( i18n("Inverse"), main );
 	cbox->setEnabled( modeInfo[mode].inverseEnable );
 	cbox->setChecked( inverse[mode] );
-	connect( cbox, SIGNAL( clicked() ), SLOT( slotInverse() ) );
+	connect( cbox, SIGNAL(clicked()), SLOT(slotInverse()) );
 	ltm->addWidget( cbox );
 
 	// gravity
 	cbox = checkGravity = new QCheckBox( i18n("Gravity"), main );
 	cbox->setChecked( gravity[mode] );
-	connect( cbox, SIGNAL( clicked() ), SLOT( slotGravity() ) );
+	connect( cbox, SIGNAL(clicked()), SLOT(slotGravity()) );
 	ltm->addWidget( cbox );
 
 	// hide background
 	cbox = checkHideBG = new QCheckBox( i18n("Hide background"), main );
 	cbox->setChecked( hideBG[mode] );
-	connect( cbox, SIGNAL( clicked() ), SLOT( slotHideBG() ) );
+	connect( cbox, SIGNAL(clicked()), SLOT(slotHideBG()) );
 	ltm->addWidget( cbox );
 	ltm->addStretch();
 
@@ -924,12 +924,12 @@ KScienceSetup::KScienceSetup(  QWidget *parent )
 	slideSize->setMinimumSize( 90, 20 );
 	slideSize->setTickPosition(QSlider::TicksBelow);
 	slideSize->setTickInterval(5);
-	connect( slideSize, SIGNAL( sliderMoved( int ) ),
-		SLOT( slotSize( int ) ) );
-	connect( slideSize, SIGNAL( sliderPressed() ),
-		SLOT( slotSliderPressed() ) );
-	connect( slideSize, SIGNAL( sliderReleased() ),
-		SLOT( slotSliderReleased() ) );
+	connect( slideSize, SIGNAL(sliderMoved(int)),
+		SLOT(slotSize(int)) );
+	connect( slideSize, SIGNAL(sliderPressed()),
+		SLOT(slotSliderPressed()) );
+	connect( slideSize, SIGNAL(sliderReleased()),
+		SLOT(slotSliderReleased()) );
 
 	ltc->addWidget( slideSize );
 
@@ -945,12 +945,12 @@ KScienceSetup::KScienceSetup(  QWidget *parent )
 	slideIntensity->setMinimumSize( 90, 20 );
 	slideIntensity->setTickPosition(QSlider::TicksBelow);
 	slideIntensity->setTickInterval(1);
-	connect( slideIntensity, SIGNAL( sliderMoved( int ) ),
-		SLOT( slotIntensity( int )) );
-	connect( slideIntensity, SIGNAL( sliderPressed() ),
-		SLOT( slotSliderPressed() ) );
-	connect( slideIntensity, SIGNAL( sliderReleased() ),
-		SLOT( slotSliderReleased() ) );
+	connect( slideIntensity, SIGNAL(sliderMoved(int)),
+		SLOT(slotIntensity(int)) );
+	connect( slideIntensity, SIGNAL(sliderPressed()),
+		SLOT(slotSliderPressed()) );
+	connect( slideIntensity, SIGNAL(sliderReleased()),
+		SLOT(slotSliderReleased()) );
 	ltc->addWidget( slideIntensity );
 
 	// speed
@@ -965,8 +965,8 @@ KScienceSetup::KScienceSetup(  QWidget *parent )
 	slideSpeed->setMinimumSize( 90, 20 );
 	slideSpeed->setTickPosition(QSlider::TicksBelow);
 	slideSpeed->setTickInterval(10);
-	connect( slideSpeed, SIGNAL( sliderMoved( int ) ),
-		SLOT( slotSpeed( int ) ) );
+	connect( slideSpeed, SIGNAL(sliderMoved(int)),
+		SLOT(slotSpeed(int)) );
 	ltc->addWidget( slideSpeed );
 
 	// motion
@@ -984,8 +984,8 @@ KScienceSetup::KScienceSetup(  QWidget *parent )
 	slideMoveX->setMinimumSize( 40, 20 );
 	slideMoveX->setTickPosition(QSlider::TicksBelow);
 	slideMoveX->setTickInterval(5);
-	connect( slideMoveX, SIGNAL( sliderMoved( int ) ),
-		SLOT( slotMoveX( int ) ) );
+	connect( slideMoveX, SIGNAL(sliderMoved(int)),
+		SLOT(slotMoveX(int)) );
 	ltcm->addWidget( slideMoveX );
 
 	slideMoveY = new QSlider(Qt::Horizontal, main );
@@ -996,8 +996,8 @@ KScienceSetup::KScienceSetup(  QWidget *parent )
 	slideMoveY->setMinimumSize( 40, 20 );
 	slideMoveY->setTickPosition(QSlider::TicksBelow);
 	slideMoveY->setTickInterval(5);
-	connect( slideMoveY, SIGNAL( sliderMoved( int ) ),
-		SLOT( slotMoveY( int ) ) );
+	connect( slideMoveY, SIGNAL(sliderMoved(int)),
+		SLOT(slotMoveY(int)) );
 	ltcm->addWidget( slideMoveY );
 
 	ltc->addStretch();
@@ -1005,7 +1005,7 @@ KScienceSetup::KScienceSetup(  QWidget *parent )
 	// preview
 	preview = new KPreviewWidget( main );
 	preview->setFixedSize( 220, 170 );
-	QPixmap p( KStandardDirs::locate("data", "kscreensaver/pics/kscience.png") );
+	QPixmap p( KStandardDirs::locate("data", QLatin1String( "kscreensaver/pics/kscience.png" )) );
 	QPalette palette;
 	if( p.isNull() ) {
 		palette.setColor( preview->backgroundRole(), Qt::black );
@@ -1056,7 +1056,7 @@ void KScienceSetup::readSettings()
 	for(int i=0; i < MAX_MODES; i++)
 	{
 		sMode.setNum( i );
-		group = KGlobal::config()->group( "Mode" + sMode );
+		group = KGlobal::config()->group( QLatin1String( "Mode" ) + sMode );
 		moveX[i]     = group.readEntry(  "MoveX",     SCI_DEFAULT_MOVEX);
 		moveY[i]     = group.readEntry(  "MoveY",     SCI_DEFAULT_MOVEY);
 		size[i]      = group.readEntry(  "Size",      SCI_DEFAULT_SIZE);
@@ -1165,7 +1165,7 @@ void KScienceSetup::slotOk()
 	for(int i=0; i<MAX_MODES; i++)
 	{
 		sMode.setNum( i );
-		group = KGlobal::config()->group("Mode" + sMode );
+		group = KGlobal::config()->group(QLatin1String( "Mode" ) + sMode );
 		group.writeEntry( "MoveX",     moveX[i]     );
 		group.writeEntry( "MoveY",     moveY[i]     );
 		group.writeEntry( "Size",      size[i]      );
